@@ -5,4 +5,4 @@ By Paul Malmsten, 2010
 pmalmsten@gmail.com
 """
 
-from xbee.xbee1 import XBee1
+from xbee.impl import XBee
